@@ -361,15 +361,28 @@ class LowRankRegressor(BaseEstimator, RegressorMixin):
         """
         return self._eig(left=left, right=right, return_type = 'default')    
     
-    def svals(self, k = 6):
+    def svals(self, k = 6, stabilizer = None):
+        """Compute the largest singular values of Z = AS (A = Koopman operator, S = injection operator)
+
+        Args:
+            k (int, optional): Number of singular values to evaluate. Defaults to 6.
+            stabilizer ([float, None], optional): A float to stabilize the inversion of K_x. It amounts to replaxe K_x -> K_x + stabilizer*Id. Defaults to None, corresponding to the pre-specified Tikhonov regularization in the RRR algorithm and to sqrt(num_points)^-1 in the PCR algorithm.
+
+        Returns:
+            NDArray: Array of the computed singular values decreasingly ordered.
+        """
         check_is_fitted(self, ['K_X_', 'K_Y_'])
         
         dim = self.K_X_.shape[0]
         inv_dim = dim**(-1)
-        try:
-            alpha = dim*self.tikhonov_reg
-        except AttributeError:
-            alpha = np.sqrt(dim) #dim*reg with reg~1/sqrt(dim)
+        if stabilizer is not None:
+            alpha = stabilizer
+        else:
+            try:
+                alpha = dim*self.tikhonov_reg
+            except AttributeError:
+                alpha = np.sqrt(dim) #dim*reg with reg~1/sqrt(dim)
+        
         K = inv_dim*(self.K_Y_@self.K_X_)
         tikhonov = aslinearoperator(diags(np.ones(dim, dtype=self.K_X_.dtype)*alpha))
         _S = eigs(K, k, aslinearoperator(self.K_X_) + tikhonov, return_eigenvectors = False)
